Wyrm = class:new()

function Wyrm:init()

	self.behavior = "follow"

	self.texture = love.graphics.newImage("res/Face.jpg")
	self.texture:setFilter('nearest','nearest')
	
	self.wait = {
		x = 0,
		y = 0,
	}
	
	self.waitC = {
		x = 0,
		y = 0,
		r = 0,
		s = 0,
	}
	
	self.waitIndicate = false

	self.position = {
		x = 375,
		y = 200,
	}
	
	self.velocity = {
		x = 0,
		y = 0,
	}
	
	self.size = {
		w = 50,
		h = 50,	
	}
	
	self.trail = {}
	
end

function Wyrm:update(dt)

	local removeTrail = {}

	table.insert(self.trail,Trail:new(self.position.x,self.position.y))
	
	for i = 1, #self.trail do
	
		self.trail[i]:update(dt)
		
		if self.trail[i].color[4] == 0 then
		
			table.insert(removeTrail, i)
		
		end
	
	end
	
	for i, v in ipairs(removeTrail) do
	
		table.remove(self.trail,v)
		
	end

	self.position.x = self.position.x + self.velocity.x * dt
	self.position.y = self.position.y + self.velocity.y * dt
	
	if self.velocity.x > 5 or self.velocity.x < -5 then
		self.velocity.x = self.velocity.x * .95
	else
		self.velocity.x = 0
	end
	
	if self.velocity.y > 5 or self.velocity.y < -5 then
		self.velocity.y = self.velocity.y * .95
	else
		self.velocity.y = 0
	end
	
	if self.behavior == "follow" then
	
		self.velocity.x = self.velocity.x + (love.mouse.getX() - self.position.x) + 300 * dt
		self.velocity.y = self.velocity.y + (love.mouse.getY() - self.position.y) + 300 * dt
	
	elseif self.behavior == "wait" then
	
		self.velocity.x = self.velocity.x + (self.wait.x - self.position.x) + 300 * dt
		self.velocity.y = self.velocity.y + (self.wait.y - self.position.y) + 300 * dt
	
	end
	
	if self.position.x < 0 then
		self.position.x = 1
		self.velocity.x = -self.velocity.x
	elseif self.position.x + self.size.w > 800 then
		self.position.x = 800 - self.size.w
		self.velocity.x = -self.velocity.x
	end
	
	if self.position.y < 0 then
		self.position.y = 1
		self.velocity.y = -self.velocity.y - 1
	elseif self.position.y + self.size.h > 425 then
		self.position.y = 425 - self.size.h - 1
		self.velocity.y = -self.velocity.y
	end
	
	if self.waitIndicate == true then
	
		self.waitC.r = self.waitC.r + 800 * dt
		self.waitC.s = self.waitC.s + 800 * dt
		
		if self.waitC.r > 2000 then
		
			self.waitIndicate = false
		
		end
	
	end

end

function Wyrm:draw()

	if self.waitIndicate == true then
	
		love.graphics.setColor(math.random(255),math.random(255),math.random(255))
		love.graphics.circle('line',self.waitC.x,self.waitC.y,self.waitC.r,self.waitC.s)
	
	end

	for i = 1, #self.trail do
	
		self.trail[i]:draw()
	
	end

	love.graphics.setColor(math.random(255),math.random(255),math.random(255))
	love.graphics.draw(self.texture,self.position.x,self.position.y)
	
	if self.behavior == "wait" then
	
		love.graphics.setColor(math.random(255),math.random(255),math.random(255))
		love.graphics.line(love.mouse.getX(),love.mouse.getY(),self.position.x + 15,self.position.y + 15)
		love.graphics.line(love.mouse.getX(),love.mouse.getY(),self.position.x + 33,self.position.y + 15)
	
	end

end

function Wyrm:mousepressed(button)

	if button == "l" then
	
		if self.behavior == "follow" then
		
			self.behavior = "wait"
			
			self.waitIndicate = true
			
			self.waitC.x = love.mouse.getX()
			self.waitC.y = love.mouse.getY()
			self.waitC.r = 1
			self.waitC.s = 1
			
			self.wait.x = love.mouse.getX()
			self.wait.y = love.mouse.getY()
		
		elseif self.behavior == "wait" then
		
			self.behavior = "follow"
		
		end
	
	end

end
